@@ -13,6 +13,7 @@ from moviebotapi.amr import AmrApi
 
 
 class MovieBotServer:
+    session: Session
     user: UserApi
     subscribe: SubscribeApi
     scraper: ScraperApi
@@ -30,6 +31,7 @@ class MovieBotServer:
             self.set_session(session)
 
     def set_session(self, session: Session):
+        self.session = session
         self.config = ConfigApi(session)
         self.user = UserApi(session)
         self.subscribe = SubscribeApi(session)
